==> plFileHandler-0.2.zip: plFileHandler/action.defaultadmin.php <==
<?php
if (!isset($gCms)) exit;
if (!$this->CheckPermission("plFileHandler_admin"))	return false;

$settings = array();
if(isset($params["submitpref"])){
	foreach($this->getSettings() as $row){
		$value = isset($params[$row[0]])?$params[$row[0]]:0;
		if($row[1] == "number")	$value = (int) $value;
		$this->SetPreference($row[0],$value);
		$settings[$row[0]] = array($value,$row[1]);
	}
	echo $this->ShowMessage($this->Lang("message_modified"));
}else{
	foreach($this->getSettings() as $row)	$settings[$row[0]] = array($this->GetPreference($row[0],$row[2]),$row[1]);
}

$active_tab = isset($params["active_tab"])?$params["active_tab"]:"settings";

echo $this->StartTabHeaders();
	echo $this->SetTabHeader("settings", $this->Lang("settings"), "settings" == $active_tab ? true : false);		
	echo $this->SetTabHeader("templates", $this->Lang("templates"), "templates" == $active_tab ? true : false);	
	echo $this->SetTabHeader("sample", $this->Lang("sample"), "sample" == $active_tab ? true : false);	
	echo $this->SetTabHeader("help", $this->Lang("helptab"), "help" == $active_tab ? true : false);		
echo $this->EndTabHeaders();


echo $this->StartTabContent();
	
	echo $this->StartTab("settings");		
		
		echo $this->CreateFormStart($id, "defaultadmin", $returnid);
		echo '<table>';
		foreach($settings as $key=>$value){
			
			echo '<tr><td>'.$this->Lang("pref_".$key).'</td><td>';
			switch($value[1]){
				case "text":
					echo $this->CreateInputText($id, $key, $value[0], 50);
					break;
				case "number":
					echo $this->CreateInputText($id, $key, $value[0], 12, 5);
					break;
				case "checkbox":
				default:
					echo $this->CreateInputCheckbox($id, $key, true, $value[0]);
					break;
			}
			echo '</td></tr>';
		}
		
		echo '<tr><td colspan="2" style="text-align: center;">'.$this->CreateInputSubmit($id, "submitpref", lang("submit")).'</td></tr>';
		echo '</table>';
		echo $this->CreateFormEnd();
		
	echo $this->EndTab();
	
	
	echo $this->StartTab("templates");
		
		$pic = '<img style="vertical-align: middle;" src="'.$gCms->config['root_url'].'/modules/plFileHandler/images/layout.gif" alt=""/> ';
		foreach(array('selector','select_image','select_file','upload','minimal') as $tpl){
			echo '<p>'.$this->CreateLink($id, "edittemplate", $returnid, $pic.'<b>'.$tpl.'</b>', array("tplname"=>$tpl)).' ('.$this->Lang('tpl_'.$tpl).')</p>';
		}
		
	echo $this->EndTab();


	echo $this->StartTab("sample");
		
		echo '<p>'.$this->Lang('help_sample').'</p>';
		echo '<p>'.$this->Lang('fieldtopopulate').' <input type="text" id="test_input"/></p>';
		echo '<br/><p>'.$this->Lang('whatusersees').'</p>';
		echo $this->DisplayInputs(array('returnInput'=>'test_input', 'mode'=>'image'));
		
	echo $this->EndTab();

	
	echo $this->StartTab("help");
		
		echo $this->GetHelpPage();
		
	echo $this->EndTab();	

echo $this->EndTabContent();

?>

==> plFileHandler-0.4.1.zip: plFileHandler/action.defaultadmin.php <==
<?php
if (!isset($gCms)) exit;
if (!$this->CheckPermission("plFileHandler_admin"))	return false;

$settings = array();
if(isset($params["submitpref"])){
	foreach($this->getSettings() as $row){
		$value = isset($params[$row[0]])?$params[$row[0]]:0;
		if($row[1] == "number")	$value = (int) $value;
		$this->SetPreference($row[0],$value);
		$settings[$row[0]] = array($value,$row[1]);
	}
	echo $this->ShowMessage($this->Lang("message_modified"));
}else{
	foreach($this->getSettings() as $row)	$settings[$row[0]] = array($this->GetPreference($row[0],$row[2]),$row[1]);
}

$active_tab = isset($params["active_tab"])?$params["active_tab"]:"settings";

echo $this->StartTabHeaders();
	echo $this->SetTabHeader("settings", $this->Lang("settings"), "settings" == $active_tab ? true : false);		
	echo $this->SetTabHeader("templates", $this->Lang("templates"), "templates" == $active_tab ? true : false);	
	echo $this->SetTabHeader("sample", $this->Lang("sample"), "sample" == $active_tab ? true : false);	
	echo $this->SetTabHeader("help", $this->Lang("helptab"), "help" == $active_tab ? true : false);		
echo $this->EndTabHeaders();


echo $this->StartTabContent();
	
	echo $this->StartTab("settings");		
		
		echo $this->CreateFormStart($id, "defaultadmin", $returnid);
		echo '<table>';
		foreach($settings as $key=>$value){
			
			echo '<tr><td>'.$this->Lang("pref_".$key).'</td><td>';
			switch($value[1]){
				case "text":
					echo $this->CreateInputText($id, $key, $value[0], 50);
					break;
				case "number":
					echo $this->CreateInputText($id, $key, $value[0], 12, 5);
					break;
				case "checkbox":
				default:
					echo $this->CreateInputCheckbox($id, $key, true, $value[0]);
					break;
			}
			echo '</td></tr>';
		}
		
		echo '<tr><td colspan="2" style="text-align: center;">'.$this->CreateInputSubmit($id, "submitpref", lang("submit")).'</td></tr>';
		echo '</table>';
		echo $this->CreateFormEnd();
		
	echo $this->EndTab();
	
	
	echo $this->StartTab("templates");
		
		$pic = '<img style="vertical-align: middle;" src="'.$gCms->config['root_url'].'/modules/plFileHandler/images/layout.gif" alt=""/> ';
		foreach(array('selector','select_image','select_file','upload','minimal') as $tpl){
			echo '<p>'.$this->CreateLink($id, "edittemplate", $returnid, $pic.'<b>'.$tpl.'</b>', array("tplname"=>$tpl)).' ('.$this->Lang('tpl_'.$tpl).')</p>';
		}
		
	echo $this->EndTab();


	echo $this->StartTab("sample");
		
		echo '<p>'.$this->Lang('help_sample').'<br/>';
		echo ($this->GetPreference('default_imagemode',true)?$this->Lang('help_currently_image'):$this->Lang('help_currently_file')).'</p>';
		echo '<p>'.$this->Lang('fieldtopopulate').' <input type="text" id="test_input"/></p>';
		echo '<br/><p>'.$this->Lang('whatusersees').'</p>';
		echo '<fieldset style="width: 300px;"><legend>Sample</legend>';
		echo $this->DisplayInputs(array('returnInput'=>'test_input'));
		echo '</fieldset>';
		
	echo $this->EndTab();

	
	echo $this->StartTab("help");
		
		echo $this->GetHelpPage();
		
	echo $this->EndTab();	

echo $this->EndTabContent();

?>
